/*jslint browser: true, nomen: true, regexp: true, plusplus: true*/
/*global define*/

var require, CKEDITOR, CKEDITOR_BASEPATH, CKEDITOR_AMD_REQUIRE,

    // CKEDITOR
    epages = {
        vars: {
            StyleUserDefinedColors: '#f00|#0f0|#0ff|#f0c'
        }
    };

require = (function (requirejs) {
    'use strict';

    var baseUrl = '../',
        deps = [],
        callback = function () {
            return;
        },

        file;

    if (window.__karma__) {
        // Set base url for karma environment
        baseUrl = '/base';

        // Push test files to dependencies stack for karma environment
        for (file in window.__karma__.files) {
            if (window.__karma__.files.hasOwnProperty(file)) {
                if (/-test.js$/.test(file)) {
                    // Convert file path to module path
                    file = file.replace(/^\/base\/(.*?)\.js$/, '$1');

                    // Add file as dependecy
                    deps.push(file);
                }
            }
        }

        // Set callback for karma environment
        callback = function () {
            window.__karma__.start();
        };

    } else if (/^.*?[\?|&]test=([^&]+).*$/.test(location.href)) {
        // Push test files if given as url get param
        file = location.href.replace(/^.*?[\?|&]test=([^&]+).*$/, '$1');
        deps.push(file);
    }

    CKEDITOR_BASEPATH = baseUrl + '/ckeditor/';

    CKEDITOR_AMD_REQUIRE = function (depends) {
        var i;

        for (i = 0; i < depends.length; i++) {
            depends[i] = (depends[i])
                .replace(CKEDITOR.basePath, 'ckeditor/')
                .replace(/(\.js(\?.*)?$)/, '');
        }

        return requirejs.apply(requirejs, arguments);
    };

    // RequireJS config
    requirejs.config({
        baseUrl: baseUrl,

        deps: deps,

        callback: callback,

        paths: {
            '$dict': 'require/$dict',
            '$i18n': 'require/$i18n',
            '$pub': 'require/$pub',
            '$ready': 'require/$ready',
            '$tmpl': 'require/$tmpl'
        },

        shim: {
            'backbone': {
                deps: ['underscore', 'jquery'],
                exports: 'Backbone'
            },
            'underscore': {
                exports: '_'
            },
            'fabric': {
                exports: 'fabric'
            },
            'ckeditor/ckeditor': {
                exports: 'CKEDITOR'
            },

            /*
             * Qunit testsuite modules
             */
            'testsuite/simulate': {
                deps: ['jquery'],
                exports: 'jQuery'
            },
            'testsuite/sinon': {
                exports: 'sinon'
            },
            'testsuite/sinon/ie': {
                deps: ['testsuite/sinon'],
                exports: 'sinon'
            },
            'testsuite/sinon/qunit': {
                deps: ['testsuite/sinon', 'testsuite/qunit'],
                exports: 'sinon'
            },
            'testsuite/sinon/server': {
                deps: ['testsuite/sinon'],
                exports: 'sinon'
            },
            'testsuite/sinon/timers-ie': {
                deps: ['testsuite/sinon', 'testsuite/simulate/timers'],
                exports: 'sinon'
            },
            'testsuite/sinon/timers': {
                deps: ['testsuite/sinon'],
                exports: 'sinon'
            }
        },

        config: {
            'ep': {
                maxContentLength: 4096,
                debugLevel: 2,
                languageId: '2',
                language: 'de',
                locale: 'de_DE',
                objectId: 0,
                viewAction: 'MBO-ViewTestcase',
                storeFrontUrl: 'http://www.DemoShop.de/Shop.sf',
                protocolAndServer: 'http://www.DemoShop.de',
                javascriptRoot: '../',

                // CKEDITOR
                features: {
                    Gadget: true,
                    Placeholder: true,
                    Blog: true,
                    Ebay: true
                },
                iconsRoot: 'myIconRoot',
                userDefinedColors: ['', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '']
            },
            'jquery/i18n': {
                region: 'de-DE',
                currency: ['EUR', 'GBP']
            },
            'jquery/dict': {
                region: 'de'
            },
            'jquery/storage': {
                namspace: '0::'
            },
            'jquery/metaparse': {
                type: 'data',
                name: 'js',
                autoparse: false
            },
            'util/mime': {
                groups: {
                    'image/*': 'image/png,image/jpeg,image/jpg,image/gif,image/vnd.microsoft.icon,image/x-icon,image/x-win-bitmap',
                    'document/*': 'application/pdf,application/msword,application/vnd.ms-excel,application/rtf,application/vnd.openxmlformats-officedocument.wordprocessingml.document,application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
                    'audio/*': 'audio/mpeg,audio/x-ms-wma,audio/ogg,audio/flac,audio/x-ms-wma',
                    'video/*': 'video/x-msvideo,video/mp4,video/mpeg,video/x-ms-wmv,video/x-flv'
                }
            },

            // CKEDITOR
            'ckeditor/config': {
                plugins: {
                    // Mediagallery cartridge
                    MediaGallery: {
                        position: 10,
                        name: 'epimage',
                        group: 'media'
                    },

                    // ExternalContent cartridge
                    Gadget: {
                        position: 20,
                        name: 'epgadget',
                        group: 'media'
                    },

                    // ExternalContent cartridge
                    Placeholder: {
                        position: 40,
                        name: 'epplaceholder'
                    },

                    // Forum cartridge
                    Blog: {
                        position: 10,
                        name: 'eppagebreak',
                        group: 'forum'
                    },

                    // Shop cartridge
                    Link: {
                        position: 10,
                        name: 'eplink',
                        group: 'various'
                    },

                    // Ebay cartridge
                    Ebay: {
                        position: 10,
                        name: 'epebay'
                    }
                }

                //,contentsCss: ['/WebRoot/Store/Shops/DemoShop/Styles/Bonjour/EditorStyle_2.css']
            }
        }
    });

    return requirejs;

}(this.requirejs));